summaryrefslogtreecommitdiff
path: root/previewer/ev-previewer.c
diff options
context:
space:
mode:
Diffstat (limited to 'previewer/ev-previewer.c')
-rw-r--r--previewer/ev-previewer.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/previewer/ev-previewer.c b/previewer/ev-previewer.c
index a836cf39..7a23b3e4 100644
--- a/previewer/ev-previewer.c
+++ b/previewer/ev-previewer.c
@@ -1,14 +1,14 @@
/* ev-previewer.c:
* this file is part of evince, a mate document viewer
*
* Copyright (C) 2009 Carlos Garcia Campos <[email protected]>
*
* Evince is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* Evince is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details.
@@ -22,8 +22,8 @@
#include <gtk/gtk.h>
#include <glib/gi18n.h>
-#include <evince-document.h>
-#include <evince-view.h>
+#include <atril-document.h>
+#include <atril-view.h>
#include "ev-previewer-window.h"
@@ -176,7 +176,7 @@ main (gint argc, gchar **argv)
ev_stock_icons_init ();
g_set_application_name (_("MATE Document Previewer"));
- gtk_window_set_default_icon_name ("evince");
+ gtk_window_set_default_icon_name ("atril");
model = ev_document_model_new ();
window = ev_previewer_window_new (model);
@@ -1,14 +1,14 @@
/* ev-previewer.c:
- * this file is part of evince, a mate document viewer
+ * this file is part of atril, a mate document viewer
*
* Copyright (C) 2009 Carlos Garcia Campos <[email protected]>
@@ -1,14 +1,14 @@
* Copyright (C) 2009 Carlos Garcia Campos <[email protected]>
*
- * Evince is free software; you can redistribute it and/or modify it
+ * Atril is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -1,14 +1,14 @@
* (at your option) any later version.
*
- * Evince is distributed in the hope that it will be useful, but
+ * Atril is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU